@@ -53,8 +53,10 @@ class BaseValidation:
 
     def handle(self, dictionary):
         boolean = True
+        
         for key in self.validations:
             if self.negated:
+                
                 if self.passes(self.find(key, dictionary), key, dictionary):
                     boolean = False
                     if hasattr(self, "negated_message"):
@@ -63,7 +65,8 @@ class BaseValidation:
                         self.error(key, self.message(key))
 
                 continue
-            if not self.passes(self.find(key, dictionary), key, dictionary):
+            attribute = self.find(key, dictionary)
+            if not self.passes(attribute, key, dictionary):
                 boolean = False
                 self.error(key, self.message(key))
 
@@ -353,7 +356,6 @@ class active_domain(BaseValidation):
 
 class numeric(BaseValidation):
     def passes(self, attribute, key, dictionary):
-        print("str", str(attribute))
         if isinstance(attribute, list):
             for value in attribute:
                 if not str(value).isdigit():
@@ -370,8 +372,26 @@ class numeric(BaseValidation):
         return "The {} must not be a numeric.".format(attribute)
 
 
+class is_list(BaseValidation):
+    def passes(self, attribute, key, dictionary):
+        return isinstance(attribute, list)
+
+    def message(self, attribute):
+        return "The {} must be a list.".format(attribute)
+
+    def negated_message(self, attribute):
+        return "The {} must not be a list.".format(attribute)
+
+
 class string(BaseValidation):
     def passes(self, attribute, key, dictionary):
+        if isinstance(attribute, list):
+            for attr in attribute:
+                if not isinstance(attr, str):
+                    return False
+
+            return True
+
         return isinstance(attribute, str)
 
     def message(self, attribute):
@@ -403,7 +423,10 @@ class length(BaseValidation):
             self.max = max
 
     def passes(self, attribute, key, dictionary):
-        return len(str(attribute)) >= self.min and len(str(attribute)) <= self.max
+        if not hasattr(attribute, "__len__"):
+            attribute = str(attribute)
+
+        return len(attribute) >= self.min and len(attribute) <= self.max
 
     def message(self, attribute):
         if self.min and not self.max:
@@ -886,6 +909,7 @@ class ValidationFactory:
             is_future,
             is_in,
             isnt,
+            is_list,
             is_past,
             ip,
             json,
